import gaphor.SysML.blocks.connectors
import gaphor.SysML.blocks.group
from gaphor.SysML.blocks.block import BlockItem
from gaphor.SysML.blocks.property import PropertyItem
from gaphor.SysML.blocks.proxyport import ProxyPortItem
